pub struct Balance {
pub immature: Arc<Amount>,
pub trusted_pending: Arc<Amount>,
pub untrusted_pending: Arc<Amount>,
pub confirmed: Arc<Amount>,
pub trusted_spendable: Arc<Amount>,
pub total: Arc<Amount>,
}Expand description
Balance, differentiated into various categories.
Fields
immature: Arc<Amount>All coinbase outputs not yet matured
trusted_pending: Arc<Amount>Unconfirmed UTXOs generated by a wallet tx
untrusted_pending: Arc<Amount>Unconfirmed UTXOs received from an external wallet
confirmed: Arc<Amount>Confirmed and immediately spendable balance
trusted_spendable: Arc<Amount>Get sum of trusted_pending and confirmed coins.
This is the balance you can spend right now that shouldn’t get cancelled via another party double spending it.
total: Arc<Amount>Get the whole balance visible to the wallet.