pub struct SyncRequest(/* private fields */);Trait Implementations
Sourceimpl<UT> LiftRef<UT> for SyncRequest
impl<UT> LiftRef<UT> for SyncRequest
type LiftType = Arc<SyncRequest>
Sourceimpl<UT> LowerError<UT> for SyncRequest
impl<UT> LowerError<UT> for SyncRequest
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for SyncRequest
impl<UT> LowerReturn<UT> for SyncRequest
Sourcetype ReturnType = <Arc<SyncRequest> as LowerReturn<UniFfiTag>>::ReturnType
type ReturnType = <Arc<SyncRequest> as LowerReturn<UniFfiTag>>::ReturnType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(obj: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(obj: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
fn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl<UT> TypeId<UT> for SyncRequest
impl<UT> TypeId<UT> for SyncRequest
const TYPE_ID_META: MetadataBuffer