pub struct TxStatus {
pub confirmed: bool,
pub block_height: Option<u32>,
pub block_hash: Option<Arc<BlockHash>>,
pub block_time: Option<u64>,
}Expand description
Transaction confirmation metadata.
Fields
confirmed: boolIs the transaction in a block.
block_height: Option<u32>Height of the block this transaction was included.
block_hash: Option<Arc<BlockHash>>Hash of the block.
block_time: Option<u64>The time shown in the block, not necessarily the same time as when the block was found.